==> kubernetes-model-1.0.45-sources.jar: annotations/io/fabric8/kubernetes/api/model/RBDVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class RBDVolumeSourceBuilder extends RBDVolumeSourceFluentImpl<RBDVolumeSourceBuilder> implements VisitableBuilder<RBDVolumeSource,RBDVolumeSourceBuilder>{

     RBDVolumeSourceFluent<?> fluent;
public RBDVolumeSourceBuilder(){
    this(new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent ){
    this(fluent, new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent , RBDVolumeSource instance ){
    this.fluent = fluent; fluent.withFsType(instance.getFsType()); fluent.withImage(instance.getImage()); fluent.withKeyring(instance.getKeyring()); fluent.withMonitors(instance.getMonitors()); fluent.withPool(instance.getPool()); fluent.withReadOnly(instance.getReadOnly()); fluent.withSecretRef(instance.getSecretRef()); fluent.withUser(instance.getUser()); 
}
public RBDVolumeSourceBuilder( RBDVolumeSource instance ){
    this.fluent = this; this.withFsType(instance.getFsType()); this.withImage(instance.getImage()); this.withKeyring(instance.getKeyring()); this.withMonitors(instance.getMonitors()); this.withPool(instance.getPool()); this.withReadOnly(instance.getReadOnly()); this.withSecretRef(instance.getSecretRef()); this.withUser(instance.getUser()); 
}

public EditableRBDVolumeSource build(){
    EditableRBDVolumeSource buildable = new EditableRBDVolumeSource(fluent.getFsType(),fluent.getImage(),fluent.getKeyring(),fluent.getMonitors(),fluent.getPool(),fluent.isReadOnly(),fluent.getSecretRef(),fluent.getUser());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
RBDVolumeSourceBuilder that = (RBDVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/RBDVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class RBDVolumeSourceBuilder extends RBDVolumeSourceFluentImpl<RBDVolumeSourceBuilder> implements VisitableBuilder<RBDVolumeSource,RBDVolumeSourceBuilder>{

     RBDVolumeSourceFluent<?> fluent;
public RBDVolumeSourceBuilder(){
    this(new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent ){
    this(fluent, new RBDVolumeSource());
}
public RBDVolumeSourceBuilder( RBDVolumeSourceFluent<?> fluent , RBDVolumeSource instance ){
    this.fluent = fluent; fluent.withFsType(instance.getFsType()); fluent.withImage(instance.getImage()); fluent.withKeyring(instance.getKeyring()); fluent.withMonitors(instance.getMonitors()); fluent.withPool(instance.getPool()); fluent.withReadOnly(instance.getReadOnly()); fluent.withSecretRef(instance.getSecretRef()); fluent.withUser(instance.getUser()); 
}
public RBDVolumeSourceBuilder( RBDVolumeSource instance ){
    this.fluent = this; this.withFsType(instance.getFsType()); this.withImage(instance.getImage()); this.withKeyring(instance.getKeyring()); this.withMonitors(instance.getMonitors()); this.withPool(instance.getPool()); this.withReadOnly(instance.getReadOnly()); this.withSecretRef(instance.getSecretRef()); this.withUser(instance.getUser()); 
}

public RBDVolumeSource build(){
    RBDVolumeSource buildable = new RBDVolumeSource(fluent.getFsType(),fluent.getImage(),fluent.getKeyring(),fluent.getMonitors(),fluent.getPool(),fluent.isReadOnly(),fluent.getSecretRef(),fluent.getUser());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
RBDVolumeSourceBuilder that = (RBDVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
